..
    Copyright (C) 2020 CERN.

    Babel-EDTF is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.


.. include:: ../README.rst

Reference
---------

.. autofunction:: babel_edtf.format_edtf

.. autofunction:: babel_edtf.edtf_to_datetime

.. autofunction:: babel_edtf.parse_edtf_level0


Additional Notes
----------------

Notes on how to contribute, legal information and changes are here for the
interested.

.. toctree::
   :maxdepth: 1

   contributing
   changes
   license
   authors
